==> activitiesprod-facade-1.0.40-sources.jar: com/bxm/activites/facade/model/ActivityDto.java <==
package com.bxm.activites.facade.model;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by wuwenquan on 2018/7/2.
 */
public class ActivityDto implements Serializable{
    private static final long serialVersionUID = -7068933184560201754L;
    /**
     *活动ID
     */
    private Long id;
    /**
     *活动状态
     */
    private Integer activityState;
    /**
     *显示状态
     */
    private Integer  showState;
    /**
     *活动名称
     */
    private  String  activityName;
    /**
     *活动策划
     */
    private  String  activityPlanner;
    /**
     *活动设计
     */
    private  String activityDesigner;
    /**
     *抽奖次数
     */
    private  Integer awardTimes;
    /**
     *活动类型
     */
    private  String activityType;
    /**
     *备用活动
     */
    private   Integer isBack;
    /**
     *活动样式
     */
    private   ActivityStyleDto activityStyle;
    private List<ActivityAwardRelationDto> activityAwardList;
    /**
     *是否主会场
     */
    private  Integer isVenue;
    /**
     *投放广告位数量
     */
     private List<ActivityPositionRelationDto> activityPositionList;
    /**
     *上线时间
     */
    private String  startTime;
    /**
     *下线时间
     */
    private  String  endTime;
    /**
     *活动链接
     */
    private  String  activityUrl;

    /**
     *活动控制
     */
    private  Integer  launchControl;
    /**
     *活动投放天数
     */
    private  String  launchWeekday;

    /**
     * 活动标签
     * */
    private  String  activityTag;

    private String apps;   // 是否支持微信。5- 不支持、1- 支持，（2－支付宝参与券编辑，暂未用到)

    private Date firstOpenTime; // 首次开启时间

    public Date getFirstOpenTime() {
        return firstOpenTime;
    }

    public void setFirstOpenTime(Date firstOpenTime) {
        this.firstOpenTime = firstOpenTime;
    }

    public String getApps() {
        return apps;
    }

    public void setApps(String apps) {
        this.apps = apps;
    }


    public String getActivityTag() {
        return activityTag;
    }

    public void setActivityTag(String activityTag) {
        this.activityTag = activityTag;
    }

    public Integer getLaunchControl() {
        return launchControl;
    }

    public void setLaunchControl(Integer launchControl) {
        this.launchControl = launchControl;
    }

    public String getLaunchWeekday() {
        return launchWeekday;
    }

    public void setLaunchWeekday(String launchWeekday) {
        this.launchWeekday = launchWeekday;
    }

    public List<ActivityAwardRelationDto> getActivityAwardList() {
        return activityAwardList;
    }

    public void setActivityAwardList(List<ActivityAwardRelationDto> activityAwardList) {
        this.activityAwardList = activityAwardList;
    }

    public Integer getShowState() {
        return showState;
    }

    public void setShowState(Integer showState) {
        this.showState = showState;
    }

    public Integer getBack() {
        return isBack;
    }

    public void setBack(Integer back) {
        isBack = back;
    }
    public Integer getIsBack() {
        return isBack;
    }

    public void setIsBack(Integer isback) {
        isBack = isback;
    }

    public Integer getVenue() {
        return isVenue;
    }

    public void setVenue(Integer venue) {
        isVenue = venue;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getActivityState() {
        return activityState;
    }

    public void setActivityState(Integer activityState) {
        this.activityState = activityState;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityPlanner() {
        return activityPlanner;
    }

    public void setActivityPlanner(String activityPlanner) {
        this.activityPlanner = activityPlanner;
    }


    public String getActivityDesigner() {
        return activityDesigner;
    }

    public void setActivityDesigner(String activityDesigner) {
        this.activityDesigner = activityDesigner;
    }

    public Integer getAwardTimes() {
        return awardTimes;
    }

    public void setAwardTimes(Integer awardTimes) {
        this.awardTimes = awardTimes;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }


    public ActivityStyleDto getActivityStyle() {
        return activityStyle;
    }

    public void setActivityStyle(ActivityStyleDto activityStyle) {
        this.activityStyle = activityStyle;
    }


    public Integer getIsVenue() {
        return isVenue;
    }

    public void setIsVenue(Integer isVenue) {
        this.isVenue = isVenue;
    }

    public List<ActivityPositionRelationDto> getActivityPositionList() {
        return activityPositionList;
    }

    public void setActivityPositionList(List<ActivityPositionRelationDto> activityPositionList) {
        this.activityPositionList = activityPositionList;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }
}

==> activitiesprod-facade-2.3.13-sources.jar: com/bxm/activites/facade/model/ActivityDto.java <==
package com.bxm.activites.facade.model;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by wuwenquan on 2018/7/2.
 */
public class ActivityDto implements Serializable{
    private static final long serialVersionUID = -7068933184560201754L;
    /**
     *活动ID
     */
    private Long id;
    /**
     *活动状态
     */
    private Integer activityState;
    /**
     *显示状态
     */
    private Integer  showState;
    /**
     *活动名称
     */
    private  String  activityName;
    /**
     *活动策划
     */
    private  String  activityPlanner;
    /**
     *活动设计
     */
    private  String activityDesigner;
    /**
     *抽奖次数
     */
    private  Integer awardTimes;
    /**
     *活动类型
     */
    private  String activityType;
    /**
     *备用活动
     */
    private   Integer isBack;
    /**
     *活动样式
     */
    private   ActivityStyleDto activityStyle;
    private List<ActivityAwardRelationDto> activityAwardList;
    /**
     *是否主会场
     */
    private  Integer isVenue;
    /**
     *投放广告位数量
     */
     private List<ActivityPositionRelationDto> activityPositionList;
    /**
     *上线时间
     */
    private String  startTime;
    /**
     *下线时间
     */
    private  String  endTime;
    /**
     *活动链接
     */
    private  String  activityUrl;

    /**
     *活动控制
     */
    private  Integer  launchControl;
    /**
     *活动投放天数
     */
    private  String  launchWeekday;

    /**
     * 活动标签
     * */
    private  String  activityTag;

    private String apps;   // 是否支持微信。5- 不支持、1- 支持，（2－支付宝参与券编辑，暂未用到)

    private Date firstOpenTime; // 首次开启时间

    /**
     * 是否自动发券（0不是 1是）
     * 是否周期投放（0不是 1是）
     *投放时段（1永久投放 2 长期投放 3节点投放）
     * 周期投放时候每天的banner的url
     */
    private Byte isAutomatic;

    private Byte isCycle;

    private Byte putInTimeType;

    private String weekdayBannerUrl;

    public Date getFirstOpenTime() {
        return firstOpenTime;
    }

    public void setFirstOpenTime(Date firstOpenTime) {
        this.firstOpenTime = firstOpenTime;
    }

    public String getApps() {
        return apps;
    }

    public void setApps(String apps) {
        this.apps = apps;
    }


    public String getActivityTag() {
        return activityTag;
    }

    public void setActivityTag(String activityTag) {
        this.activityTag = activityTag;
    }

    public Integer getLaunchControl() {
        return launchControl;
    }

    public void setLaunchControl(Integer launchControl) {
        this.launchControl = launchControl;
    }

    public String getLaunchWeekday() {
        return launchWeekday;
    }

    public void setLaunchWeekday(String launchWeekday) {
        this.launchWeekday = launchWeekday;
    }

    public List<ActivityAwardRelationDto> getActivityAwardList() {
        return activityAwardList;
    }

    public void setActivityAwardList(List<ActivityAwardRelationDto> activityAwardList) {
        this.activityAwardList = activityAwardList;
    }

    public Integer getShowState() {
        return showState;
    }

    public void setShowState(Integer showState) {
        this.showState = showState;
    }

    public Integer getBack() {
        return isBack;
    }

    public void setBack(Integer back) {
        isBack = back;
    }
    public Integer getIsBack() {
        return isBack;
    }

    public void setIsBack(Integer isback) {
        isBack = isback;
    }

    public Integer getVenue() {
        return isVenue;
    }

    public void setVenue(Integer venue) {
        isVenue = venue;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getActivityState() {
        return activityState;
    }

    public void setActivityState(Integer activityState) {
        this.activityState = activityState;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityPlanner() {
        return activityPlanner;
    }

    public void setActivityPlanner(String activityPlanner) {
        this.activityPlanner = activityPlanner;
    }


    public String getActivityDesigner() {
        return activityDesigner;
    }

    public void setActivityDesigner(String activityDesigner) {
        this.activityDesigner = activityDesigner;
    }

    public Integer getAwardTimes() {
        return awardTimes;
    }

    public void setAwardTimes(Integer awardTimes) {
        this.awardTimes = awardTimes;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }


    public ActivityStyleDto getActivityStyle() {
        return activityStyle;
    }

    public void setActivityStyle(ActivityStyleDto activityStyle) {
        this.activityStyle = activityStyle;
    }


    public Integer getIsVenue() {
        return isVenue;
    }

    public void setIsVenue(Integer isVenue) {
        this.isVenue = isVenue;
    }

    public List<ActivityPositionRelationDto> getActivityPositionList() {
        return activityPositionList;
    }

    public void setActivityPositionList(List<ActivityPositionRelationDto> activityPositionList) {
        this.activityPositionList = activityPositionList;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public Byte getIsAutomatic() {
        return isAutomatic;
    }

    public void setIsAutomatic(Byte isAutomatic) {
        this.isAutomatic = isAutomatic;
    }

    public Byte getIsCycle() {
        return isCycle;
    }

    public void setIsCycle(Byte isCycle) {
        this.isCycle = isCycle;
    }

    public Byte getPutInTimeType() {
        return putInTimeType;
    }

    public void setPutInTimeType(Byte putInTimeType) {
        this.putInTimeType = putInTimeType;
    }

    public String getWeekdayBannerUrl() {
        return weekdayBannerUrl;
    }

    public void setWeekdayBannerUrl(String weekdayBannerUrl) {
        this.weekdayBannerUrl = weekdayBannerUrl;
    }
}
